@@ -48,6 +48,9 @@ MainWindow::MainWindow(QWidget *parent)
     setWindowFlags(Qt::Window); // Enable close, minimize, and maximize buttons
     setGeneralConnections();
 
+    // Cache authentication for elevated commands
+    Cmd().runAsRoot("true", true);
+
     const auto size = this->size();
     if (settings.contains("geometry")) {
         restoreGeometry(settings.value("geometry").toByteArray());
@@ -73,16 +76,20 @@ MainWindow::MainWindow(QWidget *parent)
                      true)
               .split(' ', Qt::SkipEmptyParts);
 
-    QTimer::singleShot(0, this, [this] {
-        QTimer timer;
-        timer.start(300ms);
-        connect(&timer, &QTimer::timeout, this, [this] {
-            static bool toggle = false;
-            ui->labelCount->setText(toggle ? tr("Loading...") : QString());
-            toggle = !toggle;
-        });
+    ui->labelCount->setText(tr("Loading..."));
+    auto loadingTimer = new QTimer(this);
+    connect(loadingTimer, &QTimer::timeout, this, [this]() {
+        static bool toggle = false;
+        ui->labelCount->setText(toggle ? tr("Loading...") : QString());
+        toggle = !toggle;
+    });
+    loadingTimer->start(300);
+
+    // Load services asynchronously to keep UI responsive
+    QTimer::singleShot(0, this, [this, loadingTimer] {
         listServices();
-        timer.disconnect();
+        loadingTimer->stop();
+        loadingTimer->deleteLater();
         displayServices();
         ui->listServices->setFocus();
     });
@@ -159,7 +166,7 @@ void MainWindow::cmdDone()
     setCursor(QCursor(Qt::ArrowCursor));
 }
 
-void MainWindow::setGeneralConnections()
+void MainWindow::setGeneralConnections() noexcept
 {
     connect(ui->comboFilter, &QComboBox::currentTextChanged, this, &MainWindow::displayServices);
     connect(ui->lineSearch, &QLineEdit::textChanged, this, &MainWindow::displayServices);
@@ -171,7 +178,7 @@ void MainWindow::setGeneralConnections()
     connect(ui->pushStartStop, &QPushButton::clicked, this, &MainWindow::pushStartStop_clicked);
 }
 
-QString MainWindow::getHtmlColor(const QColor &color)
+QString MainWindow::getHtmlColor(const QColor &color) noexcept
 {
     return QString("#%1%2%3")
         .arg(color.red(), 2, 16, QChar('0'))
@@ -191,7 +198,7 @@ void MainWindow::listServices()
 
 void MainWindow::processNonSystemdServices()
 {
-    const auto list = cmd.getOut("/sbin/service --status-all", true).trimmed().split("\n");
+    const auto list = cmd.getOutAsRoot("/sbin/service --status-all", true).trimmed().split("\n");
     QRegularExpression re("dpkg-.*$");
     services.reserve(list.size());
 
@@ -299,7 +306,7 @@ void MainWindow::processSystemdMaskedServices(QStringList &names)
     names = QStringList(nameSet.begin(), nameSet.end());
 }
 
-void MainWindow::displayServices()
+void MainWindow::displayServices() noexcept
 {
     ui->listServices->blockSignals(true);
     ui->listServices->clear();
@@ -380,6 +387,7 @@ void MainWindow::pushAbout_clicked()
 
 void MainWindow::pushEnableDisable_clicked()
 {
+    ui->pushEnableDisable->setEnabled(false);
     savedRow = ui->listServices->currentRow();
     auto service = ui->listServices->currentItem()->text();
     auto *ptrService = ui->listServices->currentItem()->data(Qt::UserRole).value<Service *>();
@@ -398,6 +406,7 @@ void MainWindow::pushEnableDisable_clicked()
         emit ui->listServices->currentItemChanged(ui->listServices->currentItem(), ui->listServices->currentItem());
         QMessageBox::information(this, tr("Success"), tr("%1 was disabled.").arg(service));
     }
+    ui->pushEnableDisable->setEnabled(true);
 }
 
 void MainWindow::pushHelp_clicked()
@@ -408,6 +417,7 @@ void MainWindow::pushHelp_clicked()
 
 void MainWindow::pushStartStop_clicked()
 {
+    ui->pushStartStop->setEnabled(false);
     savedRow = ui->listServices->currentRow();
     auto service = ui->listServices->currentItem()->text();
     auto *ptrService = ui->listServices->currentItem()->data(Qt::UserRole).value<Service *>();
@@ -430,4 +440,5 @@ void MainWindow::pushStartStop_clicked()
             QMessageBox::information(this, tr("Success"), tr("%1 was stopped.").arg(service));
         }
     }
+    ui->pushStartStop->setEnabled(true);
 }
